#! /bin/sh
#
# 	Part of kde-service-menu-steghide Version 0.2
# 	Copyright (C) 2009-2012 Giuseppe Benigno <giuseppe.benigno(at)gmail.com>
#
# 	This program is free software: you can redistribute it and/or modify
# 	it under the terms of the GNU General Public License as published by
# 	the Free Software Foundation, either version 3 of the License, or
# 	(at your option) any later version.
#
# 	This program is distributed in the hope that it will be useful,
# 	but WITHOUT ANY WARRANTY; without even the implied warranty of
# 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# 	GNU General Public License for more details.
#
# 	You should have received a copy of the GNU General Public License
# 	along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

lang=`echo "${1}" | sed -e "s/@//g"` && shift || exit
action="${1}" && shift || exit
workDir="${1%/*}"
[ -d "${workDir}" ] && [ -w "${workDir}" ] || workDir="./"
fileName="${1##*/}" # file name without path
baseFileName="${fileName%.*}" # file name without path and extension

#### languages strings messages #################
# Sintax for strings name is: msg_[$action]_$window_[$section]
# For languages as sr@Latn use srLatn

load_language_en () {
	msg_warning_title="Steghide warning!"
	msg_mount_abort="Operation aborted"

	msg_embed_fileToHide_title="File to hide"
	msg_embed_passwd_title="Password"
	msg_embed_passwd_text="Choose password or leave empty for no password:"
	msg_embed_confirm_passwd_text="Retype password (for sure)."
	msg_embed_passwd_error_title="Error"
	msg_embed_passwd_error_text="Passwords don't match. Ending script."
	msg_embed_saveFile_title="Save data"
	msg_embed_extract_error_title="Error"
	msg_embed_extract_error_text="Steghide ended with error."
	msg_embed_finish_title="Embedding file"
	msg_embed_finish_text="File embeddes in:"

	msg_extract_passwd_title="Request password"
	msg_extract_passwd_text="Type password or leave empty for no password:"
	msg_extract_infoWarning_title="Warning"
	msg_extract_infoWarning_text="This file doesn't contain any embedded file or the password is wrong."
	msg_extract_fileExist_title="File exist"
	msg_extract_fileExist_text1="File \"${fileName}\" contain"
	msg_extract_fileExist_text2="but a file with same name already exists. Do you want overwrite?."
	msg_extract_save_title="Save"
	msg_extract_extraxtError_title="Error"
	msg_extract_extractError_text="Error in extraction operation."
	msg_extract_finish_title="Extracting file"
	msg_extract_finish_text="The embedded file in \"${fileName}\" was saved as:"
}

load_language_it () {
	msg_warning_title="Avviso Steghide!"
	msg_mount_abort="Operazione annullata"

	msg_embed_fileToHide_title="File da nascondere"
	msg_embed_passwd_title="Password"
	msg_embed_passwd_text="Scegli la password o lasciare il campo vuoto se non si vuole una password:"
	msg_embed_confirm_passwd_text="Riscrivi la password (per sicurezza)"
	msg_embed_passwd_error_title="Errore"
	msg_embed_passwd_error_text="Le password inserite non corrispondono."
	msg_embed_saveFile_title="Salva"
	msg_embed_extract_error_title="Errore"
	msg_embed_extract_error_text="Steghide non è riuscito a completare l'operazione."
	msg_embed_finish_title="Inclusione file"
	msg_embed_finish_text="File incluso in:"

	msg_extract_passwd_title="Richiesta password"
	msg_extract_passwd_text="Inserisci la password o lasciare il campo vuoto se non se ne vuole una:"
	msg_extract_infoWarning_title="Attenzione"
	msg_extract_infoWarning_text="Questo file non contiene altri file o la password inserita non è corretta."
	msg_extract_fileExist_title="Il file esiste"
	msg_extract_fileExist_text1="Il file \"${fileName}\" contiene"
	msg_extract_fileExist_text2="ma un file con lo stesso nome esiste già. Vuoi sovrascriverlo?."
	msg_extract_save_title="Salva"
	msg_extract_extraxtError_title="Errore"
	msg_extract_extractError_text="Si è verificato un errore durante l'operazione di estrazione."
	msg_extract_finish_title="Estrazione file"
	msg_extract_finish_text="Il file contenuto in \"${fileName}\" è stato salvato come:"
}

################################################

abortPassivePopup () {
	kdialog --title "${msg_warning_title}" --passivepopup "${msg_mount_abort}" 5
	exit
}

embed () {
	file_to_hide=$(kdialog --title "${msg_embed_fileToHide_title}" --caption "${msg_embed_fileToHide_title}" --icon document-encrypt --getopenfilename .) || abortPassivePopup
	file_to_hideName="${file_to_hide##*/}"

	pass=$(kdialog --title "${msg_embed_passwd_title}" --caption "${msg_embed_passwd_title}" --icon document-encrypt --password "${msg_embed_passwd_text}") || abortPassivePopup
	if [ -n "${pass}" ]; then
		pass2=$(kdialog --title "${msg_embed_passwd_title}" --caption "${msg_embed_passwd_title}" --icon document-encrypt --password "${msg_embed_confirm_passwd_text}") || abortPassivePopup
		[ x"${pass}" != x"${pass2}" ] && kdialog --title "${msg_embed_passwd_error_title}" --caption "${msg_embed_passwd_error_title}" --icon document-encrypt --sorry "${msg_embed_passwd_error_text}" && exit
	fi

	file_to_save=$(kdialog --title "${msg_embed_saveFile_title}" --caption "${msg_embed_saveFile_title}" --icon document-encrypt --getsavefilename "${fileName%.*} (${file_to_hideName}).${fileName##*.}") || abortPassivePopup
	steghide embed -cf "$1" -ef "${file_to_hide}" -p "${pass}" -sf "${file_to_save}" -v -f && kdialog --title "${msg_embed_finish_title}" --passivepopup "${msg_embed_finish_text} \"${file_to_save}\"" 5 || kdialog --title "${msg_embed_extract_error_title}" --caption "${msg_embed_extract_error_title}" --icon document-encrypt --error "${msg_embed_extract_error_text}"
}

extract () {
	pass=$(kdialog --title "${msg_extract_passwd_title}" --caption "${msg_extract_passwd_title}" --icon document-decrypt --password "${msg_extract_passwd_text}") || abortPassivePopup

	#testing if the file realy contain another file and if so, getting its name
	file_to_save=$(steghide info "$1" -p "${pass}" | grep embedded | sed "s/ *embedded *file *\"\(.*\)\":.*/\1/")
	[ "${#file_to_save}" = "0" ] && kdialog --title "${msg_extract_infoWarning_title}" --caption "${msg_extract_infoWarning_title}" --icon document-decrypt --sorry "${msg_extract_infoWarning_text}" && exit
	if [ -f "${workDir}/${file_to_save}" ]; then
		kdialog --title "${msg_extract_fileExist_title}" --caption "${msg_extract_fileExist_title}" --icon document-decrypt --warningyesno "${msg_extract_fileExist_text1} \"${file_to_save}\" ${msg_extract_fileExist_text2}"
		[ $? != 0 ] && file_to_save=$(kdialog --title "${msg_extract_save_title}" --caption "${msg_extract_save_title}" --icon document-decrypt --getsavefilename "${file_to_save%.*}.${file_to_save##*.}") || abortPassivePopup
	fi

	steghide extract -sf "$1" -xf "${file_to_save}" -p "${pass}" -f -v && 	kdialog --title "${msg_extract_finish_title}" --caption "${msg_extract_finish_title}" --passivepopup "${msg_extract_finish_text} \"${file_to_save##*/}\"" 5 || kdialog --title "${msg_extract_extraxtError_title}" --caption "${msg_extract_extraxtError_title}" --error "${msg_extract_extractError_text}"
}

#### main

cd "${workDir}"
    "load_language_${lang}" || load_language_en
    "${action}" "${@}"
cd -
